@@ -2262,6 +2262,29 @@ Socket(fam, SOCK_DCCP, IPPROTO_DCCP)
 	family = fam;
 }
 
+DCCPSocket::DCCPSocket(DCCPSocket& server, timeout_t timeout) :
+Socket(accept(server.so, NULL, NULL))
+{
+	family = server.family;
+	Socket::state = CONNECTED;
+	socklen_t alen = sizeof(peer);
+
+	getpeername(so, (struct sockaddr *)&peer, &alen);	
+
+	switch(family) {
+#ifdef	CCXX_IPV6
+	case IPV6:
+		if(!server.onAccept(IPV6Host(peer.ipv6.sin6_addr), peer.ipv6.sin6_port))
+			endSocket();
+		break;
+#endif
+	case IPV4:
+		if(!server.onAccept(IPV4Host(peer.ipv4.sin_addr), peer.ipv4.sin_port))
+			endSocket();
+		break;
+	}
+}
+
 #ifdef	HAVE_GETADDRINFO
 DCCPSocket::DCCPSocket(const char *name, Family fam, unsigned backlog) :
 Socket(fam, SOCK_DCCP, IPPROTO_DCCP)
@@ -2740,23 +2763,23 @@ void DCCPSocket::connect(const IPV6Host &host, tpport_t port, timeout_t timeout)
 }
 #endif
 
-bool DCCPSocket::setCCID(uint8_t ccid)
+bool DCCPSocket::setCCID(uint8 ccid)
 {
-	uint8_t ccids[4];             /* for getting the available CCIDs, should be large enough */
-	socklen_t len = sizeof (ccids);
+	uint8 ccids[16];             /* for getting the available CCIDs, should be large enough */
+	socklen_t len = sizeof(ccids);
 	int ret;
 	bool ccid_supported = false;
 
 	/*
 	 * Determine which CCIDs are available on the host
 	 */
-	ret = getsockopt (so, SOL_DCCP, DCCP_SOCKOPT_AVAILABLE_CCIDS, &ccids, &len);
+	ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_AVAILABLE_CCIDS, (char *)&ccids, &len);
 	if (ret < 0) {
 		cout << "Can not determine available CCIDs" << endl;
 		return false;
 	}
 
-	for (unsigned i = 0; i < sizeof (ccids); i++) {
+	for (unsigned i = 0; i < sizeof(ccids); i++) {
 		if (ccid == ccids[i]) {
 			ccid_supported = true;
 			break;
@@ -2768,7 +2791,7 @@ bool DCCPSocket::setCCID(uint8_t ccid)
 		return false;
 	}
 
-	if (setsockopt (so, SOL_DCCP, DCCP_SOCKOPT_CCID, &ccid, sizeof (ccid)) < 0) {
+	if (setsockopt(so, SOL_DCCP, DCCP_SOCKOPT_CCID, (char *)&ccid, sizeof (ccid)) < 0) {
 		cout << "Can not set CCID" << endl;
 		return false;
 	}
@@ -2776,6 +2799,34 @@ bool DCCPSocket::setCCID(uint8_t ccid)
 	return true;
 }
 
+int DCCPSocket::getTxCCID()
+{
+    int ccid, ret;
+    socklen_t ccidlen;
+
+    ccidlen = sizeof(ccid);
+    ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_TX_CCID, &ccid, &ccidlen);
+    if (ret < 0) {
+        cout << "Can not determine get current TX CCID value" << endl;
+        return -1;
+    }
+    return ccid;
+}
+
+int DCCPSocket::getRxCCID()
+{
+    int ccid, ret;
+    socklen_t ccidlen;
+
+    ccidlen = sizeof(ccid);
+    ret = getsockopt(so, SOL_DCCP, DCCP_SOCKOPT_RX_CCID, &ccid, &ccidlen);
+    if (ret < 0) {
+        cout << "Can not determine get current RX CCID value" << endl;
+        return -1;
+    }
+    return ccid;
+}
+
 TCPStream::TCPStream(TCPSocket &server, bool throwflag, timeout_t to) :
 	streambuf(), Socket(accept(server.getSocket(), NULL, NULL)),
 #ifdef	HAVE_OLD_IOSTREAM
