@@ -1,27 +1,28 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -102,50 +103,47 @@ extern "C" {
 static int _wrap_mutex_init(void **priv)
 {
 	return _gcry_mutex_init((Mutex **)(priv));
-}
+	}
 
 static int _wrap_mutex_destroy(void **priv)
 {
 	return _gcry_mutex_destroy((Mutex **)(priv));
-}
+	}
 
 static int _wrap_mutex_lock(void **priv)
 {
 	return _gcry_mutex_lock((Mutex **)(priv));
-}
+	}
 
 static int _wrap_mutex_unlock(void **priv)
 {
-        return _gcry_mutex_unlock((Mutex **)(priv));
-}
+		return _gcry_mutex_unlock((Mutex **)(priv));
+	}
 
 static struct gcry_thread_cbs _gcry_threads =
 {
 	GCRY_THREAD_OPTION_PTHREAD, NULL,
 	_wrap_mutex_init, _wrap_mutex_destroy,
 	_wrap_mutex_lock, _wrap_mutex_unlock
-};
+	};
 
 };
 
 #endif
 
-static class _ssl_global
-{
+static class _ssl_global {
 public:
-	_ssl_global()
-	{
+	_ssl_global() {
 #ifndef	WIN32
 		gcry_control(GCRYCTL_SET_THREAD_CBS, &_gcry_threads);
 #endif
 		gnutls_global_init();
 	}
 
-	~_ssl_global()
-	{
+	~_ssl_global() {
 		gnutls_global_deinit();
 	}
-		
+
 } _ssl_global;
 #endif
 
@@ -159,7 +157,7 @@ static void ssl_lock(int mode, int n, const char *file, int line)
 		ssl_mutex[n].enter();
 	else
 		ssl_mutex[n].leave();
-}
+	}
 
 static unsigned long ssl_thread(void)
 {
@@ -168,14 +166,12 @@ static unsigned long ssl_thread(void)
 #else
 	return (unsigned long)pthread_self();
 #endif
-}
+	}
 } // extern "C"
 
-static class _ssl_global
-{
+static class _ssl_global {
 public:
-	_ssl_global()
-	{
+	_ssl_global() {
 		if(ssl_mutex)
 			return;
 
@@ -187,8 +183,7 @@ public:
 		CRYPTO_set_locking_callback(ssl_lock);
 	}
 
-	~_ssl_global()
-	{
+	~_ssl_global() {
 		if(!ssl_mutex)
 			return;
 		CRYPTO_set_id_callback(NULL);
@@ -234,10 +229,8 @@ ssize_t SSLStream::readLine(char *str, size_t request, timeout_t timeout)
 	if(!ssl)
 		return Socket::readLine(str, request, timeout);
 
-	while(count < request)
-	{
-		if(timeout && !isPending(pendingInput, timeout))
-		{
+	while(count < request) {
+		if(timeout && !isPending(pendingInput, timeout)) {
 			error(errTimeout, "Read timeout", 0);
 			return -1;
 		}
@@ -247,14 +240,12 @@ ssize_t SSLStream::readLine(char *str, size_t request, timeout_t timeout)
 #else
 		nstat = SSL_read(ssl, str + count, 1);
 #endif
-		if(nstat <= 0)
-		{
+		if(nstat <= 0) {
 			error(errInput, "Could not read from socket", socket_errno);
 			return -1;
 		}
 
-		if(str[count] == '\n')
-		{
+		if(str[count] == '\n') {
 			if(count > 0 && str[count - 1] == '\r')
 				--count;
 			break;
@@ -274,10 +265,8 @@ ssize_t SSLStream::writeData(void *source, size_t size, timeout_t timeout)
 
 	const char *slide = (const char *)source;
 
-	while(size)
-	{
-		if(timeout && !isPending(pendingOutput, timeout))
-		{
+	while(size) {
+		if(timeout && !isPending(pendingOutput, timeout)) {
 			error(errOutput);
 			return -1;
 		}
@@ -287,8 +276,7 @@ ssize_t SSLStream::writeData(void *source, size_t size, timeout_t timeout)
 #else
 		nstat = SSL_write(ssl, slide, size);
 #endif
-		if(nstat <= 0)
-		{
+		if(nstat <= 0) {
 			error(errOutput);
 			return -1;
 		}
@@ -310,12 +298,9 @@ ssize_t SSLStream::readData(void *target, size_t size, char separator, timeout_t
 	if(separator == 0x0d || separator == 0x0a)
 		return readLine((char *)target, size, timeout);
 
-	if(separator)
-	{
-		while(count < size)
-		{
-			if(timeout && !isPending(pendingInput, timeout))
-			{
+	if(separator) {
+		while(count < size) {
+			if(timeout && !isPending(pendingInput, timeout)) {
 				error(errTimeout, "Read timeout", 0);
 				return -1;
 			}
@@ -325,8 +310,7 @@ ssize_t SSLStream::readData(void *target, size_t size, char separator, timeout_t
 #else
 			nstat = SSL_read(ssl, str + count, 1);
 #endif
-			if(nstat <= 0)
-			{
+			if(nstat <= 0) {
 				error(errInput, "Could not read from socket", socket_errno);
 				return -1;
 			}
@@ -336,11 +320,10 @@ ssize_t SSLStream::readData(void *target, size_t size, char separator, timeout_t
 		}
 		if(str[count] == separator)
 			str[count] = 0;
-		return count;		
+		return count;
 	}
 
-	if(timeout && !isPending(pendingInput, timeout))
-	{
+	if(timeout && !isPending(pendingInput, timeout)) {
 		error(errTimeout);
 		return -1;
 	}
@@ -350,19 +333,18 @@ ssize_t SSLStream::readData(void *target, size_t size, char separator, timeout_t
 #else
 	nstat = SSL_read(ssl, target, size);
 #endif
-	
-	if(nstat < 0)
-	{
+
+	if(nstat < 0) {
 		error(errInput);
 		return -1;
 	}
 	return nstat;
-}	
+}
 
 #ifdef	CCXX_GNUTLS
 bool SSLStream::getSession(void)
 {
-    	const int cert_priority[3] =
+		const int cert_priority[3] =
 		{GNUTLS_CRT_X509, GNUTLS_CRT_OPENPGP, 0};
 
 	if(ssl)
@@ -370,10 +352,9 @@ bool SSLStream::getSession(void)
 
 	if(so == INVALID_SOCKET)
 		return false;
-	
+
 	ssl = new SSL;
-	if(gnutls_init(&ssl->session, GNUTLS_CLIENT))
-	{
+	if(gnutls_init(&ssl->session, GNUTLS_CLIENT)) {
 		delete ssl;
 		ssl = NULL;
 		return false;
@@ -384,8 +365,7 @@ bool SSLStream::getSession(void)
 	gnutls_certificate_type_set_priority(ssl->session, cert_priority);
 	gnutls_credentials_set(ssl->session, GNUTLS_CRD_CERTIFICATE, ssl->xcred);
 	gnutls_transport_set_ptr(ssl->session, (gnutls_transport_ptr)so);
-	if(gnutls_handshake(ssl->session))
-	{
+	if(gnutls_handshake(ssl->session)) {
 		gnutls_deinit(ssl->session);
 		gnutls_certificate_free_credentials(ssl->xcred);
 		delete ssl;
@@ -407,28 +387,25 @@ bool SSLStream::getSession(void)
 		return false;
 
 	ctx = SSL_CTX_new(SSLv3_client_method());
-	if(!ctx)
-	{
+	if(!ctx) {
 		SSL_CTX_free(ctx);
 		return false;
 	}
 
 	ssl = SSL_new(ctx);
-	if(!ssl)
-	{
+	if(!ssl) {
 		SSL_CTX_free(ctx);
 		return false;
 	}
 
 	SSL_set_fd(ssl, so);
 	SSL_set_connect_state(ssl);
-	err = SSL_connect(ssl);	
+	err = SSL_connect(ssl);
 
 	if(err < 0)
 		SSL_shutdown(ssl);
 
-	if(err <= 0)
-	{
+	if(err <= 0) {
 		SSL_free(ssl);
 		SSL_CTX_free(ctx);
 		ssl = NULL;
@@ -436,7 +413,7 @@ bool SSLStream::getSession(void)
 	}
 	return true;
 }
-#endif	
+#endif
 
 #ifdef	CCXX_GNUTLS
 void SSLStream::endStream(void)
@@ -444,14 +421,13 @@ void SSLStream::endStream(void)
 	if(ssl && so != INVALID_SOCKET)
 		gnutls_bye(ssl->session, GNUTLS_SHUT_WR);
 	TCPStream::endStream();
-	if(ssl)
-	{
+	if(ssl) {
 		gnutls_deinit(ssl->session);
 		gnutls_certificate_free_credentials(ssl->xcred);
 		delete ssl;
 		ssl = NULL;
 	}
-}	
+}
 
 void SSLStream::disconnect(void)
 {
@@ -460,19 +436,17 @@ void SSLStream::disconnect(void)
 
 	if(so != INVALID_SOCKET)
 		TCPStream::disconnect();
-	if(ssl)
-	{
+	if(ssl) {
 		gnutls_deinit(ssl->session);
 		gnutls_certificate_free_credentials(ssl->xcred);
 		delete ssl;
 		ssl = NULL;
 	}
 }
-#else	
+#else
 void SSLStream::disconnect(void)
 {
-	if(ssl)
-	{
+	if(ssl) {
 		if(so != INVALID_SOCKET)
 			SSL_shutdown(ssl);
 		SSL_free(ssl);
@@ -483,8 +457,7 @@ void SSLStream::disconnect(void)
 
 void SSLStream::endStream(void)
 {
-	if(ssl)
-	{
+	if(ssl) {
 		if(so != INVALID_SOCKET)
 			SSL_shutdown(ssl);
 		SSL_free(ssl);
