@@ -40,7 +40,7 @@
 
 #include "SampleObject.h"
 
-IMPLEMENT_PERSISTENCE(Test,"Test");
+IMPLEMENT_PERSISTENCE(Test,"Test")
 
 Test::Test()
 : iInteger(0), strString("Null"), strString2("Null")
