@@ -9,7 +9,7 @@ using namespace ost;
 #endif
 
 // Test if cancellation unwinds stack frame
-// 
+//
 
 class myObject
 {
@@ -26,8 +26,7 @@ class myThread: public Thread
 public:
 	myThread() : Thread() {};
 
-	void run(void)
-	{
+	void run(void) {
 		myObject obj;
 		setCancel(cancelImmediate);
 		Thread::sleep(TIMEOUT_INF);
